unit uNSClient;

interface

uses
    Windows,
    Messages,
    SysUtils,
    Classes,
    Graphics,
    Dialogs,
    Controls,
    Registry,
    ScktComp,
    libSystem,
    jwaPdh,
    jwapdhmsg,
    ExtCtrls,
    JclFileUtils,
    JclSYSInfo,
    inifiles,
    StrUtils,
    DateUtils,
    SvCom_NTService;

type
  TNSClient = class(TNtService)
    ServerSocket1: TServerSocket;
    CPUTimer1: TTimer;
    procedure ServiceAfterInstall(Sender: TObject);
    procedure ServiceAfterUninstall(Sender: TObject);
    procedure ServiceStop(Sender: TNtService; var DoAction: Boolean);
    procedure ServiceStart(Sender: TNtService; var DoAction: Boolean);
    procedure CPUTimerTimer(Sender: TObject);
    procedure ServerSocketClientRead(Sender: TObject; Socket: TCustomWinSocket);
  private
    verInfo : TJclFileVersionInfo;
    fSentCPUEvent: boolean;
    IsPDHOpen : boolean;
    nDebugLevel : Integer;
    sCounterSystemTotalProcessorTime : string;
    sCounterSystemSystemUpTime : string;
    sCounterMemoryCommitLimit : string;
    sCounterMemoryCommitByte : string;
    sPassword : string;
    CPUBuffer : TCircularBuffer;
    query : HQUERY;
    cpu_counter : HCOUNTER;
    CounterValue: TPdhFmtCounterValue;
    lnUptime : Int64;
    uptime_counter : HCOUNTER;
    mem_commitLimit_counter : HCOUNTER;
    mem_commitByte_counter : HCOUNTER;
    lnMemCommitLimit : Int64;
    lnMemCommitByte: Int64;
    asArgv : array of string;

    function PDHCheck(sCounter: string; const Error: Cardinal): Longint;
    function PdhGetErrorMsg(sCounter : string; const Error: Cardinal) : string;
    procedure CollectData;
    procedure AddCounters;
    function FindAnswer(sRequest: string) : String;
    procedure SetArgvFromRequest(sRequest : string);
    function ProcessServReq: string;
    function ProcessProcReq: string;
    function ProcessCounterReq(sCounter : string): string;
    function ProcessInstancesReq(sCounter : LPCSTR): string;
    { Private declarations }
  public
    { Public declarations }
  end;

  //Record to hold the information from one thread
  TThreadInfo = record
    Active       : Boolean;
    ThreadHandle : integer;
    ThreadId     : Cardinal;
    CurrentFile  : string;
  end;

  // Requests constants declaration
  const REQ_VERSION = 1;
	const REQ_CPUTOTAL = 2;
	const REQ_UPTIME = 3;
  const REQ_FREESPACE = 4;
  const REQ_SERVICESTATE = 5;
  const REQ_RUNNINGPROCESS = 6;
  const REQ_MEMORYUSE = 7;
  const REQ_COUNTER = 8 ;
  const REQ_FILEAGE = 9;
  const REQ_INSTANCES = 10;

  function FileTime2DateTime(FileTime: TFileTime): TDateTime;
  Function GetFileAge(sFilename : string) : string;

var
  NSClient: TNSClient;

implementation

{$R *.DFM}

function TNSClient.PdhCheck(sCounter : string; const Error: Cardinal) : Longint;
  // Purpose	: Check wrapper for all PDH queries
begin
  PdhCheck := Error;
  //if (Error <> ERROR_SUCCESS) and (nDebugLevel > 1) then
    //WriteToEventLog('NSClient Warning: PDH.dll fails during a call for ' + sCounter + ' / ' + PdhGetErrorMsg(sCounter, Error),1)
end;


function TNSClient.PdhGetErrorMsg(sCounter : string; const Error: Cardinal) : string;
  // Purpose	: Return a string corresponding to the error
  // Created	: YR - 23.02.2001
begin
  case Error of
    PDH_CSTATUS_ITEM_NOT_VALIDATED: PdhGetErrorMsg := sCounter + ' - ERROR: ITEM_NOT_VALIDATED';
  else
    PdhGetErrorMsg := sCounter + ' - ERROR: 0x' + IntToHex(Error,8)
  end
end;


Procedure TNSClient.CollectData;
	// Purpose	: Get CPU load and add it to a circular buffer
	// Created	: YR - 21.11.2000
begin
  // Get the informations
  if not IsPDHOpen then AddCounters;
  PdhCheck('Collect', PdhCollectQueryData(query));

  // Process CPU counter
  PdhCheck('Collect CPU', PdhGetFormattedCounterValue(cpu_counter, PDH_FMT_LARGE, nil, CounterValue));
  case CounterValue.CStatus of
    PDH_CSTATUS_NEW_DATA: CPUBuffer.Push(CounterValue.LargeValue);
    PDH_CSTATUS_VALID_DATA: CPUBuffer.Push(CounterValue.LargeValue);
  else
    if fSentCPUEvent = false then
    begin
      WriteToEventLog('NSClient CollectData: Call to retrieve counter value for ' + sCounterSystemTotalProcessorTime + ' failed, returning status code ' + IntToStr(CounterValue.CStatus) + '.',2);
      fSentCPUEvent:= true;
    end;
  end;

  // Process Uptime counter
  PdhCheck('Collect Uptime',PdhGetFormattedCounterValue(uptime_counter, PDH_FMT_LARGE, nil, CounterValue));
  case CounterValue.CStatus of
    PDH_CSTATUS_NEW_DATA: lnUptime:=CounterValue.LargeValue;
    PDH_CSTATUS_VALID_DATA: lnUptime:=CounterValue.LargeValue;
  end;

  // Process memory counters
  PdhCheck('Collect CommitLimit',PdhGetFormattedCounterValue(mem_commitLimit_counter, PDH_FMT_LARGE, nil, CounterValue));
  case CounterValue.CStatus of
    PDH_CSTATUS_NEW_DATA, PDH_CSTATUS_VALID_DATA: lnMemCommitLimit:=CounterValue.LargeValue;
  end;

  PdhCheck('Collect CommitByte',PdhGetFormattedCounterValue(mem_commitByte_counter, PDH_FMT_LARGE, nil, CounterValue));
  case CounterValue.CStatus of
    PDH_CSTATUS_NEW_DATA, PDH_CSTATUS_VALID_DATA: lnMemCommitByte :=CounterValue.LargeValue;
  end;
end;


Procedure TNSClient.AddCounters;
begin
  try
  // Create the PDH handle to collect CPU and uptime informations
  PdhCheck('OpenQuery Standard', pdhOpenQuery(nil,0,query));
  // Initialize the CPU Counter query
  PdhCheck(sCounterSystemTotalProcessorTime, pdhAddCounter(query,PChar('\\' + Get_ComputerName +
  sCounterSystemTotalProcessorTime),0,cpu_counter));
  // Initialize the uptime counter query
  PdhCheck(sCounterSystemSystemUpTime, pdhAddCounter(query,PChar('\\' + Get_ComputerName +
  sCounterSystemSystemUpTime),0,uptime_counter));
  // Initialize the memory counters
  PdhCheck(sCounterMemoryCommitLimit, pdhAddCounter(query,PChar('\\' + Get_ComputerName +
  sCounterMemoryCommitLimit),0,mem_commitLimit_counter));
  PdhCheck(sCounterMemoryCommitByte, pdhAddCounter(query,PChar('\\' + Get_ComputerName +
  sCounterMemoryCommitByte),0,mem_commitByte_counter));
  IsPDHOpen := true;
  // change the frequency of the timer
  CPUTimer1.Interval := 5000;
  // Start listening to the port.
  ServerSocket1.Active:=True;
  WriteToEventLog('NSClient is now responding to queries.',0);
  except
      on E: Exception do
      begin
        WriteToEventLog(E.Message,2);
        Application.Destroy;
      end;
  end;
end;


Function TNSClient.FindAnswer(sRequest: string) : String;
	// Purpose	: Process all requests from the plugin
	// Created	: YR - 22.11.2000
var
  nres : Integer;
	begin
    SetArgvFromRequest(sRequest);	// split the string into a string array
    try
			if sPassword = asArgv[0] then
      begin
        // If the first argument is not a number, Delphi will generate an exception
        case StrToIntDef(asArgv[1],0) of
          REQ_VERSION: FindAnswer := verInfo.BinFileVersion;
          REQ_CPUTOTAL:
          begin
            nres :=  CPUBuffer.GetAverage(StrToIntDef(asArgv[2],60)*12);
            if nres >= 0 then
              FindAnswer := IntToStr(nres)
            else
              FindAnswer := '0';
          end;
          REQ_UPTIME: FindAnswer:= IntToStr(lnUptime);
          REQ_FREESPACE: FindAnswer:=IntToStr(GetFreeSpace(strupper(PChar(asArgv[2])))) + '&' +
          IntToStr(GetDiskSize(strupper(PChar(asArgv[2]))));
          REQ_SERVICESTATE: FindAnswer:= ProcessServReq;
          REQ_RUNNINGPROCESS: FindAnswer := ProcessProcReq;
          REQ_MEMORYUSE: FindAnswer := IntToStr(lnMemCommitLimit) + '&' + IntToStr(lnMemCommitByte);
          REQ_COUNTER: FindAnswer := ProcessCounterReq(asArgv[2]);
          REQ_FILEAGE: FindAnswer := GetFileAge(asArgv[2]);
          REQ_INSTANCES: FindAnswer := ProcessInstancesReq(LPCSTR(asArgv[2]));
        else
          FindAnswer:= 'ERROR: Unknown request number';
        end;
      end
    else
      FindAnswer:= 'ERROR:Wrong password';
    except
      on E: Exception do
      begin
        FindAnswer := 'ERROR: Malformed request or internal error. Check EventLog:' +sRequest;
        WriteToEventLog(E.Message,2);
      end;
  end;
end;


Procedure TNSClient.SetArgvFromRequest(sRequest : string);
	// Purpose	: Set the asArgv array according to the request we received
	// Created	: YR - 22.11.2000
var
  nPos : integer;
  nArgs : integer;
  i: integer;
begin
  SetLength(asArgv,10);
  for i:=0 to length(asArgv)-1 do asArgv[i]:='';	// Fill the params array with ''

  // Fill the array
  nArgs:=0;
  nPos := Pos('&',sRequest);
  while nPos>0 do
  begin
    asArgv[nArgs] := copy(sRequest,1,nPos-1);		// Get the parameter
    sRequest := copy(sRequest, nPos+1, maxint);	// Remove the parameter from the request
    inc(nArgs);             							// inc number of parameters
    if nArgs>=length(asArgv) then    				// increase array if too small
      setlength(asArgv,length(asArgv)+10);
    nPos := Pos('&',sRequest);							// look for another parameters
  end;
  asArgv[nArgs]:=sRequest;
  SetLength(asArgv,nArgs+1);								// set the length of the array
end;


function TNSClient.ProcessServReq: string;
  // Purpose	: Check the state of all services and return a status and
  // 				the faulty services
	// Created	: YR - 27.11.2000
var
  i : integer;			// loop's index
  s : string;				// answer
  nState : integer;		// Overall service state
  bShowAll : boolean;	// true is we have to display started services too
  servicelist : TStrings;
begin
  nState := 0;							// OK State
  s := '';
  bShowAll := False;
  if length(asArgv) >= 4 then	// minimum number of parameters
  begin

  if asArgv[3] = 'ALL' then
  begin
    servicelist:=TStringList.Create;
    ServiceGetList( '', SERVICE_WIN32, SERVICE_STATE_ALL, servicelist);
    for i:=0 to (servicelist.Count-1) do
      s:= s + servicelist[i] + ',';
    servicelist.free;
    nState:=1;
  end
  else begin

    // Do we have to return started services too ?
    if strupper(PChar(asArgv[2])) = 'SHOWALL' then
      bShowAll:=true;

    // Loop on every service we have to check
    for i:=3 to length(asArgv)-1 do
      if ServiceRunning('',asArgv[i]) then
      begin
        // Service is running
        if bShowAll=True then s := s + ' ' + asArgv[i] + ': Started -'
      end
      else if (ServiceStopped('',asArgv[i])) then
      begin
        // Service is stopped
        s := s + ' ' + asArgv[i] +': Stopped -';
        nState := 2;
      end
    else begin
      // service is unknown
      s := s + ' ' + asArgv[i] +': Unknown -';
      if (nState<1) then nState := 1;
    end;
    ;

    if length(s)=0 then
      s := 'All services are running'		// if everything's fine
    else
      SetLength(s,length(s)-1);				// remove trailing -
		end
  
  end;
  ProcessServReq := IntToStr(nState) + '&' + s;
   
end;


function TNSClient.ProcessProcReq: string;
  // Purpose	: Check if all process are running and
  //					return a status and the faulty processes
	// Created	: YR - 28.11.2000
var
  i : integer;			// loop's index
  s : string;				// answer
  nState : integer;		// Overall Process state
  bShowAll : boolean;	// true is we have to display all processes
begin
  nState := 0;							// OK State
  s := '';
  bShowAll := False;
  if length(asArgv) >= 4 then // minimum number of parameters
  begin
    // Do we have to return running process too ?
    if strupper(PChar(asArgv[2])) = 'SHOWALL' then
      bShowAll:=true;

    // Loop on every process we have to check
    for i:=3 to length(asArgv)-1 do
      if ProcessRunning(asArgv[i]) then
      begin
        // Process is running
        if bShowAll=True then s := s + ' ' + asArgv[i] + ': Running -'
      end
      else begin
        // Process is not running
        s := s + ' ' + asArgv[i] +': not running -';
        nState := 2;
      end;
      ;
    if length(s)=0 then
      s := 'All processes are running'		// if everything's fine
    else
      SetLength(s,length(s)-1);				// remove trailing -
  end
  else begin
    // not enough parameters
    s := 'No process to check';
    nState := -1;
  end;
  ProcessProcReq := IntToStr(nState) + '&' + s;
end;


function TNSClient.ProcessCounterReq(sCounter : string) : string;
  // Purpose	: Get information about any counter. Just be sure it exists!
	// Created	: YR - 22.02.2001
  // Updated  : TS - 03.05.2003 - added second call to PdhCollectQueryData with sleep
  //            to enable proper function of counters that require two values for the
  //            PdhGetFormattedCounterValue function to work correctly.
var
  qryPDHQuery : HQUERY;
  custom_counter : HCOUNTER;
  lStatus : cardinal;
begin
  // WriteToEventLog('NSClient DEBUG: Custom Counter : ' + sCounter);

  // Open a new query
  PdhCheck('OpenQuery' + sCounter, pdhOpenQuery(nil,0,qryPDHQuery));

  // Add the counter
  lStatus := PdhCheck('Add ' + sCounter,pdhAddCounter(qryPDHQuery,PChar('\\' + Get_ComputerName + sCounter),0,custom_counter));

  if lStatus <> ERROR_SUCCESS then
    // Counter is invalid
    ProcessCounterReq := PdhGetErrorMsg(sCounter, lStatus)
  else begin
    // Counter is valid
    // Collect the data
    PdhCheck('Collect ' + sCounter, PdhCollectQueryData(qryPDHQuery));
    sleep(1000);
    PdhCheck('Collect ' + sCounter, PdhCollectQueryData(qryPDHQuery));

    // Process Custom counter
    PdhCheck(sCounter, PdhGetFormattedCounterValue(custom_counter, PDH_FMT_DOUBLE, nil, CounterValue));

    case CounterValue.CStatus of
      PDH_CSTATUS_NEW_DATA, PDH_CSTATUS_VALID_DATA : ProcessCounterReq :=
               FloatToStrF(CounterValue.doubleValue,ffFixed,15,5);
    else
      ProcessCounterReq := PdhGetErrorMsg(sCounter, Error)
    end;
  end;

  // Close the query
  pdhCheck('Close ' + sCounter, pdhCloseQuery(qryPDHQuery));
end;


function TNSClient.ProcessInstancesReq(sCounter : LPCSTR) : string;
  // Purpose	: Get Instances for requested counter!
	// Created	: TS - 07.05.2003
var
  p : PChar;
  counterListLen, instanceListLen : DWORD;
  counterBuffer, instanceBuffer : PChar;
  res : string;
  temp : string;
  position : integer;
  templen : integer;
  begin
    counterListLen := 0;
    instanceListLen := 0;
    res:='';

    // The first call to PdhEnumObjectItems returns back how big the buffers need to be
    PdhCheck('Instances ' + sCounter, PdhEnumObjectItems (Nil, Nil, PChar (sCounter), Nil, counterListLen, Nil, instanceListLen, PERF_DETAIL_COSTLY, 0));
    GetMem (counterBuffer, counterListLen);
    GetMem (instanceBuffer, instanceListLen);

    try
      // Now with properly sized buffers we fill them with the second call
      PdhCheck('Instances ' + sCounter, PdhEnumObjectItems (Nil, Nil, PChar (sCounter), counterBuffer, counterListLen, instanceBuffer, instanceListLen, PERF_DETAIL_COSTLY, 0));

      p := instanceBuffer;
      if Assigned (p) then
        while p^ <> #0 do
        begin
          // Assign to a string to make it easier to work with
          temp:= (p);
          
          // Cleanup instance return the value that it would expect back in a request
          // LogicalDisk
          if UpperCase(sCounter) = 'LOGICALDISK' then
          begin
            position:= pos('/', temp);
            templen:= length(temp);
            temp:= AnsiMidStr(temp, (position+1), (templen-position));
          end;

          if res='' then
            res:= temp
          else
            res:=concat(res, ',', temp);
          Inc (p, lstrlen (p) + 1)
       end;
    finally
      FreeMem (InstanceBuffer);
      FreeMem (counterBuffer)
    end;
    ProcessInstancesReq := res;
end;



procedure TNSClient.CPUTimerTimer(Sender: TObject);
  // Purpose	: Collect CPU load data
	// Created	: YR - 22.11.2000
begin
  try
    CollectData;
  except
    WriteToEventLog('NSClient Error: CollectData failed',1);
  end;
end;


procedure TNSClient.ServiceAfterInstall(Sender: TObject);
  // Purpose	: Add the registry entries after the service is installed
	// Created	: YR - 28.11.2000
var
  Reg: TRegistry;
begin
  try
    Reg := TRegistry.Create;
    Reg.RootKey:= HKEY_LOCAL_MACHINE;
    if not Reg.KeyExists('\Software\NSClient\Params') then
    begin
      // if the key doesn't exist, let's create it.
      Reg.CreateKey('\Software\NSClient\Params');
      Reg.OpenKey('\Software\NSClient\Params',true);
      Reg.WriteInteger ('port',1248);
      Reg.WriteString ('password','None');
    end;
    WriteToEventLog('NSClient installed',0);
  except;
    WriteToEventLog('NSClient installation failed',2);
  end;
end;

procedure TNSClient.ServiceAfterUninstall(Sender: TObject);
  // Purpose	: Remove the registry entries after the servie is uninstalled
	// Created	: YR - 28.11.2000
var
  Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey:= HKEY_LOCAL_MACHINE;

  if Reg.KeyExists('\Software\NSClient\Params') then
  begin
    Reg.DeleteValue('port');
    Reg.DeleteValue('password');
    Reg.DeleteKey('\Software\NSClient\Params');
    Reg.DeleteKey('\Software\NSClient');
  end;
  WriteToEventLog('NSClient has been uninstalled',0);
end;

procedure TNSClient.ServiceStop(Sender: TNtService; var DoAction: Boolean);
  // Purpose	: Release the PDH query
	// Created	: YR - 23.02.2001
begin
  //CPUTimer.Enabled := false;
  //PdhCheck('Close standard', pdhCloseQuery(query));
  DoAction := true;
  WriteToEventLog('NSClient has stopped',0);
end;

procedure TNSClient.ServiceStart(Sender: TNtService; var DoAction: Boolean);
  // Purpose	: Initialize the counters
  // Created	: YR - 21.11.2000
var
  Reg: TRegistry;
  langid : int64;
  iniFile : TIniFile;
begin
  IsPDHOpen := false;
  langid := GetSystemDefaultLangID();
  if FileExists(PathExtractFileDirFixed(ParamStr(0)) + 'counters.defs') then
    WriteToEventLog('NSClient is reading ' + PathExtractFileDirFixed(ParamStr(0)) + 'counters.defs' + ' for counters definitions. Language code : 0x' + IntToHex(langid,4),0)
  else
    WriteToEventLog('NSClient Warning: The counters definitions file ' + PathExtractFileDirFixed(ParamStr(0)) + 'counters.defs' + ' doesn''t exist. You can safely disregard this message on English version OS! OS Language code : 0x' + IntToHex(langid,4),0);

    // no issue if the file doesn't exist!
    iniFile := TIniFile.Create(PathExtractFileDirFixed(ParamStr(0)) + 'counters.defs');
    if GetWindowsVersion in [wvWinNT4] then
    begin
      // NT 4
      sCounterSystemTotalProcessorTime := iniFile.ReadString ('0x' + IntToHex(langid,4), 'NT4_SystemTotalProcessorTime', '\System\% Total Processor Time');
      sCounterSystemSystemUpTime := iniFile.ReadString ('0x' + IntToHex(langid,4), 'NT4_SystemSystemUpTime', '\System\System Up Time');
      sCounterMemoryCommitLimit := iniFile.ReadString ('0x' + IntToHex(langid,4), 'NT4_MemoryCommitLimit', '\Memory\Commit Limit');
      sCounterMemoryCommitByte := iniFile.ReadString ('0x' + IntToHex(langid,4), 'NT4_MemoryCommitByte', '\Memory\Committed Bytes');
    end
    else begin
      // Win2K
      sCounterSystemTotalProcessorTime := iniFile.ReadString ('0x' + IntToHex(langid,4), 'W2K_SystemTotalProcessorTime', '\Processor(_total)\% Processor Time');
      sCounterSystemSystemUpTime := iniFile.ReadString ('0x' + IntToHex(langid,4), 'W2K_SystemSystemUpTime', '\System\System Up Time');
      sCounterMemoryCommitLimit := iniFile.ReadString ('0x' + IntToHex(langid,4), 'W2K_MemoryCommitLimit', '\Memory\Commit Limit');
      sCounterMemoryCommitByte := iniFile.ReadString ('0x' + IntToHex(langid,4), 'W2K_MemoryCommitByte', '\Memory\Committed Bytes');
    end;
    iniFile.Free;

    try
			CPUBuffer := TCircularBuffer.Create(17280);
      verInfo := TJclFileVersionInfo.Create(ParamStr(0));

			// Read config informations in the registry
      Reg := TRegistry.Create;
      Reg.RootKey:= HKEY_LOCAL_MACHINE;
      if not Reg.KeyExists('\Software\NSClient\Params') then
      begin
        ServerSocket1.port := 1248;
        sPassword := 'None';
      end
	   	else begin
        Reg.OpenKey('\Software\NSClient\Params',true);
        ServerSocket1.Active := false;
        ServerSocket1.port := Reg.ReadInteger('port');
        sPassword := Reg.ReadString('password');
        nDebugLevel := 0;
        if Reg.ValueExists('DebugLevel') then
          nDebugLevel := Reg.ReadInteger('DebugLevel')
      end;
      Reg.CloseKey;
      Reg.Free;
      CPUTimer1.Enabled := true;
      DoAction := true;
      WriteToEventLog('NSClient ' + verInfo.BinFileVersion + ' has started. Language code : 0x' + IntToHex(langid,4) + '. DebugLevel: ' + IntToStr(nDebugLevel),0);
    except
      DoAction := false;
      WriteToEventLog('NSClient Error: Service ' + verInfo.BinFileVersion + ' start failed',2);
  end;
end;

function FileExistsEx(const FileNameWithWildCards:string):boolean;
var SR:TSearchRec;
    Res:integer;
begin
  Res := SysUtils.FindFirst(FileNameWithWildCards, faAnyFile, SR);
  SysUtils.FindClose(SR);
  // Result := (Res <> 0);
  Result := (Res = 0);
end;

Function GetFileAge(sFilename : string) : string;
  // Purpose	: Return information about last written and age of a file
  // Created	: YR - 24.02.2002

var
  FileDateTime: TDateTime;
  SysDateTime : TDateTime;
  diffDateTime : TDateTime;
  SysTime: TSystemTime;
  nMinutes : Extended;
begin
  if FileExistsEx(sFileName) then
  begin
    FileDateTime := FileTime2DateTime(GetFileLastWrite(sFileName));
    GetLocalTime(SysTime);
    SysDateTime := SystemTimeToDateTime(SysTime);
    diffDateTime := SysDateTime-FileDateTime;
    nMinutes := int(diffDateTime * 1440);
    GetFileAge := FloatToStr(nMinutes) + '&' + IntToStr(DateTimeToUnix(FileDateTime));
  end
  else
    GetFileAge := 'ERROR: file not found';
end;




function FileTime2DateTime(FileTime: TFileTime): TDateTime;
   // Copyright  2001 Ernesto D'Spirito
var
  LocalFileTime: TFileTime;
  SystemTime: TSystemTime;
begin
  FileTimeToLocalFileTime(FileTime, LocalFileTime);
  FileTimeToSystemTime(LocalFileTime, SystemTime);
  Result := SystemTimeToDateTime(SystemTime);
end;

procedure TNSClient.ServerSocketClientRead(Sender: TObject; Socket: TCustomWinSocket);
	// Purpose	: Receive the TCP requests and send the answer to the plugin
	// Created	: YR - 22.11.2000
begin
  Socket.SendText(FindAnswer(Socket.ReceiveText));
end;



end.









